==> nettoe_1.3.2.orig.tar.gz: nettoe-1.3.2/src/network.h <==
/* netToe Version 1.3.0
 * Release date: 24 February 2010
 * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
 *		
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef	_NETWORK_H
#define _NETWORK_H 1

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <stdio.h>
#include <string.h> 
#include <errno.h>
#include <signal.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/wait.h>
#include <netdb.h>

                     
extern int establish_listening_socket ( unsigned short port_number, char peer_ip_address[INET6_ADDRSTRLEN]);
extern int connect_to_socket ( char host_ip_number[INET6_ADDRSTRLEN], unsigned short port_number );
extern int write_to_socket ( int connected_socket, char *buffer, int bytes );
extern int read_from_socket (int connected_socket, char *buffer, int bytes);

extern void give_local_IP ( char * local_ip_address );

/* extern const char *give_local_hostname ( void ); */ /* NOT USED */

#endif	/* _NETWORK_H */

==> nettoe_1.4.2.orig.tar.gz: nettoe-1.4.2/src/network.h <==
/* netToe Version 1.4.1
 *
 * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
 *           2009-2013 Mats Erik Andersson <meand@users.sourceforge.net>
 *		
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef	_NETWORK_H
#define _NETWORK_H 1

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <stdio.h>
#include <string.h> 
#include <errno.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <sys/wait.h>
#include <netdb.h>

                     
extern int establish_listening_socket ( unsigned short port_number, char *peer_ip_address, int bytes);
extern int connect_to_socket ( char *host_ip_number, unsigned short port_number );
extern int write_to_socket ( int connected_socket, char *buffer, int bytes );
extern int read_from_socket ( int connected_socket, char *buffer, int bytes );

extern void give_local_IP ( char * local_ip_address, int bytes );

/* extern const char *give_local_hostname ( void ); */ /* NOT USED */

#endif	/* _NETWORK_H */
